@@ -419,7 +419,6 @@ gail_window_ref_relation_set (AtkObject *obj)
   AtkObject *array[1];
   AtkRelation* relation;
   GtkWidget *current_widget;
-  gboolean ret;
 
   gail_return_val_if_fail (GAIL_IS_WIDGET (obj), NULL);
 
@@ -440,8 +439,7 @@ gail_window_ref_relation_set (AtkObject *obj)
         {
           atk_relation_set_remove (relation_set, relation);
         }
-      ret = gtk_tooltips_get_info_from_tip_window (GTK_WINDOW (widget), NULL, &current_widget);
-      if (ret)
+      if (GTK_WIDGET_VISIBLE(widget) && gtk_tooltips_get_info_from_tip_window (GTK_WINDOW (widget), NULL, &current_widget))
         {
           array [0] = gtk_widget_get_accessible (current_widget);
 
